@@ -12,6 +12,7 @@ from bs4.element import NavigableString
 from bs4.element import Tag
 from dateutil.parser import parse as parse_date
 
+from .connection import root
 from .exceptions import DisabledAccount
 from .exceptions import NoTitle
 from .exceptions import NonePage
@@ -21,7 +22,7 @@ from .exceptions import ParsingError
 from .exceptions import ServerError
 from .exceptions import _raise_exception
 
-mentions_regexp: Pattern = re_compile(r"^(?:(?:https?://)?(?:www.)?furaffinity.net)?/user/([^/#]+).*$")
+mentions_regexp: Pattern = re_compile(r"^(?:(?:https?://)?(?:www\.)?furaffinity.net)?/user/([^/#]+).*$")
 watchlist_next_regexp: Pattern = re_compile(r"/watchlist/(by|to)/[^/]+/\d+")
 not_found_messages: tuple[str, ...] = ("not in our database", "cannot be found", "could not be found", "user not found")
 deactivated_messages: tuple[str, ...] = ("deactivated", "pending deletion")
@@ -31,34 +32,6 @@ def parse_page(text: str) -> BeautifulSoup:
     return BeautifulSoup(text, "lxml")
 
 
-def check_page(page: BeautifulSoup) -> int:
-    """
-    0 if page is okay
-    1 if page is None
-    2 if page has no title
-    3 if page is from a disabled account
-    4 if page is a not found error
-    5 if page is a system error
-    6 if page has a notice-message (error)
-    """
-
-    try:
-        check_page_raise(page)
-        return 0
-    except NonePage:
-        return 1
-    except NoTitle:
-        return 2
-    except DisabledAccount:
-        return 3
-    except NotFound:
-        return 4
-    except SystemError:
-        return 5
-    except NoticeMessage:
-        return 6
-
-
 def check_page_raise(page: BeautifulSoup) -> None:
     if page is None:
         raise NonePage
@@ -132,6 +105,8 @@ def parse_journal_page(journal_page: BeautifulSoup) -> dict[str, Any]:
     tag_id: Optional[Tag] = journal_page.select_one("meta[property='og:url']")
     tag_title: Optional[Tag] = journal_page.select_one("h2.journal-title")
     tag_date: Optional[Tag] = journal_page.select_one("span.popup_date")
+    tag_header: Optional[Tag] = journal_page.select_one("div.journal-header")
+    tag_footer: Optional[Tag] = journal_page.select_one("div.journal-footer")
     tag_content: Optional[Tag] = journal_page.select_one("div.journal-content")
     tag_comments: Optional[Tag] = journal_page.select_one("div.section-footer > span")
 
@@ -144,6 +119,8 @@ def parse_journal_page(journal_page: BeautifulSoup) -> dict[str, Any]:
     id_: int = int(tag_id.attrs.get("content", "0").strip("/").split("/")[-1])
     title: str = tag_title.text.strip()
     date: datetime = parse_date(tag_date.attrs["title"].strip())
+    header: str = "".join(map(str, tag_header.children)).strip() if tag_header else ""
+    footer: str = "".join(map(str, tag_footer.children)).strip() if tag_footer else ""
     content: str = "".join(map(str, tag_content.children)).strip()
     mentions: list[str] = parse_mentions(tag_content)
     comments: int = int(tag_comments.text.strip())
@@ -156,6 +133,8 @@ def parse_journal_page(journal_page: BeautifulSoup) -> dict[str, Any]:
         "title": title,
         "date": date,
         "content": content,
+        "header": header,
+        "footer": footer,
         "mentions": mentions,
         "comments": comments,
     }
@@ -228,6 +207,7 @@ def parse_submission_page(sub_page: BeautifulSoup) -> dict[str, Any]:
     tag_favorites: Optional[Tag] = sub_page.select_one("div.favorites span")
     tag_rating: Optional[Tag] = sub_page.select_one("div.rating span")
     tag_type: Optional[Tag] = sub_page.select_one("div#submission_page[class^='page-content-type']")
+    tag_fav: Optional[Tag] = sub_page.select_one("div.fav > a")
     tag_info: Optional[Tag] = sub_page.select_one("section.info.text")
 
     assert tag_info is not None, _raise_exception(ParsingError("Missing info tag"))
@@ -252,6 +232,7 @@ def parse_submission_page(sub_page: BeautifulSoup) -> dict[str, Any]:
     assert tag_favorites is not None, _raise_exception(ParsingError("Missing favorites tag"))
     assert tag_rating is not None, _raise_exception(ParsingError("Missing rating tag"))
     assert tag_type is not None, _raise_exception(ParsingError("Missing type tag"))
+    assert tag_fav is not None, _raise_exception(ParsingError("Missing fav tag"))
     assert tag_category1 is not None, _raise_exception(ParsingError("Missing category1 tag"))
     assert tag_category2 is not None, _raise_exception(ParsingError("Missing category2 tag"))
     assert tag_species is not None, _raise_exception(ParsingError("Missing species tag"))
@@ -287,6 +268,8 @@ def parse_submission_page(sub_page: BeautifulSoup) -> dict[str, Any]:
         tag_prev.attrs["href"].split("/")[-2]) if tag_prev and tag_prev.text.lower() == "prev" else None
     next_sub: Optional[int] = int(
         tag_next.attrs["href"].split("/")[-2]) if tag_next and tag_next.text.lower() == "next" else None
+    fav_link: Optional[str] = f"{root}{href}" if (href := tag_fav.attrs["href"]).startswith("/fav/") else None
+    unfav_link: Optional[str] = f"{root}{href}" if (href := tag_fav.attrs["href"]).startswith("/unfav/") else None
 
     return {
         "id": id_,
@@ -309,6 +292,8 @@ def parse_submission_page(sub_page: BeautifulSoup) -> dict[str, Any]:
         "thumbnail_url": thumbnail_url,
         "prev": prev_sub,
         "next": next_sub,
+        "fav_link": fav_link,
+        "unfav_link": unfav_link,
     }
 
 
@@ -322,6 +307,7 @@ def parse_user_page(user_page: BeautifulSoup) -> dict[str, Any]:
     tag_infos: list[Tag] = user_page.select("div#userpage-contact-item div.table-row")
     tag_contacts: list[Tag] = user_page.select("div#userpage-contact div.user-contact-user-info")
     tag_user_icon_url: Optional[Tag] = user_page.select_one("img.user-nav-avatar")
+    tag_user_nav_controls: Optional[Tag] = user_page.select_one("div.user-nav-controls")
 
     assert tag_status is not None, _raise_exception(ParsingError("Missing name tag"))
     assert tag_profile is not None, _raise_exception(ParsingError("Missing profile tag"))
@@ -330,6 +316,10 @@ def parse_user_page(user_page: BeautifulSoup) -> dict[str, Any]:
     assert tag_watchlist_to is not None, _raise_exception(ParsingError("Missing watchlist to tag"))
     assert tag_watchlist_by is not None, _raise_exception(ParsingError("Missing watchlist by tag"))
     assert tag_user_icon_url is not None, _raise_exception(ParsingError("Missing user icon URL tag"))
+    assert tag_user_nav_controls is not None, _raise_exception(ParsingError("Missing user nav controls tag"))
+
+    tag_watch: Optional[Tag] = tag_user_nav_controls.select_one("a[href^='/watch/'], a[href^='/unwatch/']")
+    tag_block: Optional[Tag] = tag_user_nav_controls.select_one("a[href^='/block/'], a[href^='/unblock/']")
 
     status: str = (u := tag_status.text.strip())[0]
     name: str = u[1:]
@@ -359,6 +349,12 @@ def parse_user_page(user_page: BeautifulSoup) -> dict[str, Any]:
         contacts[tag_key.text.strip()] = a.attrs["href"] if (a := pc.select_one("a")) else \
             [*filter(bool, map(str.strip, pc.text.split("\n")))][-1]
     user_icon_url: str = "https:" + tag_user_icon_url.attrs["src"]
+    tag_watch_href: str = tag_watch.attrs["href"] if tag_watch else ""
+    watch: Optional[str] = f"{root}{tag_watch_href}" if tag_watch_href.startswith("/watch/") else None
+    unwatch: Optional[str] = f"{root}{tag_watch_href}" if tag_watch_href.startswith("/unwatch/") else None
+    tag_block_href: str = tag_block.attrs["href"] if tag_block else ""
+    block: Optional[str] = f"{root}{tag_block_href}" if tag_block_href.startswith("/block/") else None
+    unblock: Optional[str] = f"{root}{tag_block_href}" if tag_block_href.startswith("/unblock/") else None
 
     return {
         "name": name,
@@ -370,6 +366,10 @@ def parse_user_page(user_page: BeautifulSoup) -> dict[str, Any]:
         "info": info,
         "contacts": contacts,
         "user_icon_url": user_icon_url,
+        "watch": watch,
+        "unwatch": unwatch,
+        "block": block,
+        "unblock": unblock,
     }
 
 
@@ -486,33 +486,12 @@ def parse_user_favorites(favorites_page: BeautifulSoup) -> dict[str, Any]:
 def parse_user_journals(journals_page: BeautifulSoup) -> dict[str, Any]:
     user_info: dict[str, str] = parse_user_folder(journals_page)
     sections: list[Tag] = journals_page.select("section[id^='jid:']")
-    last_page: bool = not any(b.text.lower() == "next" for b in journals_page.select("form button.button"))
+    next_page_tag: Optional[Tag] = journals_page.select_one("div.mini-nav > div.mini-nav-cell:first-child > a.button")
 
     return {
         **user_info,
         "sections": sections,
-        "last_page": last_page,
-    }
-
-
-def parse_search_submissions(search_page: BeautifulSoup) -> dict[str, Any]:
-    tag_stats: Optional[Tag] = search_page.select_one("div[id='query-stats']")
-    assert tag_stats is not None, _raise_exception(ParsingError("Missing stats tag"))
-
-    for div in tag_stats.select(""):
-        div.decompose()
-    a, b, tot = 0, 0, 0
-    if s := search(r"(\d+)[^\d]*(\d+)[^\d]*(\d+)", tag_stats.text.strip()):
-        a, b, tot = map(int, s.groups())
-    figures: list[Tag] = search_page.select("figure[id^='sid-']")
-    last_page: bool = not any(b.text.lower() == "next" for b in search_page.select("button.button:not(.disabled)"))
-
-    return {
-        "from": (a or 1) - 1,
-        "to": (b or 1) - 1,
-        "total": tot,
-        "figures": figures,
-        "last_page": last_page
+        "last_page": next_page_tag is None,
     }
 
 
