@@ -143,6 +143,8 @@ class Submission(SubmissionBase):
         self.thumbnail_url: str = ""
         self.prev: Optional[int] = None
         self.next: Optional[int] = None
+        self.favorite: bool = False
+        self.favorite_toggle_link: str = ""
         from .comment import Comment
         self.comments: list[Comment] = []
 
@@ -167,6 +169,8 @@ class Submission(SubmissionBase):
         yield "thumbnail_url", self.thumbnail_url
         yield "prev", self.prev
         yield "next", self.next
+        yield "favorite", self.favorite
+        yield "favorite_toggle_link", self.favorite_toggle_link
         from .comment import _remove_recursion
         yield "comments", [dict(_remove_recursion(c)) for c in self.comments]
 
@@ -207,5 +211,7 @@ class Submission(SubmissionBase):
         self.thumbnail_url = parsed["thumbnail_url"]
         self.prev = parsed["prev"]
         self.next = parsed["next"]
+        self.favorite = parsed["unfav_link"] is not None
+        self.favorite_toggle_link = parsed["fav_link"] or parsed["unfav_link"]
         from .comment import sort_comments, Comment
         self.comments = sort_comments([Comment(t, self) for t in parse_comments(self.submission_page)])
